@@ -4,7 +4,8 @@ maxLikEstimator <- function(x, model){
   
   # Function to use:
   distFun <- switch(distribution,
-          "Gaussian" = maxLikEstimator_Gauss)
+          "Gaussian" = maxLikEstimator_Gauss,
+          "Ising" = maxLikEstimator_Ising)
   
   # Run and return:
   distFun(x, model)
