@@ -71,6 +71,7 @@ dlvm1 <- function(
   estimator = "ML",
   optimizer = "default",
   storedata = FALSE,
+  verbose = TRUE,
   sampleStats
 ){
   covtype <- match.arg(covtype)
@@ -88,12 +89,12 @@ dlvm1 <- function(
   #   stop("'lambda_between' may not be a string")
   # }
   # 
-  if (missing(lambda)){
-    stop("'lambda' may not be missing")
-  }
-  if (is.character(lambda)){
-    stop("'lambda' may not be a string")
-  }
+  # if (missing(lambda)){
+  #   stop("'lambda' may not be missing")
+  # }
+  # if (is.character(lambda)){
+  #   stop("'lambda' may not be a string")
+  # }
   
   
   # Match args:
@@ -145,6 +146,27 @@ dlvm1 <- function(
   # Number of variables:
   nVar <- nrow(vars)
   
+  # Check lambda:
+  if (missing(lambda)){
+    if (verbose){
+      message("'lambda' is missing, creating observed data only model.")
+    }
+    
+    lambda <- diag(nVar)
+    O <- matrix(0, nVar, nVar)
+    omega_epsilon_within <- O
+    delta_epsilon_within <- O
+    kappa_epsilon_within <- O
+    sigma_epsilon_within <- O
+    lowertri_epsilon_within <- O
+    
+    omega_epsilon_between <- O
+    delta_epsilon_between <- O
+    kappa_epsilon_between <- O
+    sigma_epsilon_between <- O
+    lowertri_epsilon_between <- O
+  }
+  
   # Number of measurements:
   nTime <- ncol(vars)
   
