@@ -6,7 +6,7 @@ prune <- function(
   adjust = c( "none", "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr"),
   matrices, # Automatically chosen
   runmodel = TRUE,
-  recursive = TRUE,
+  recursive = FALSE,
   verbose = TRUE,
   log = TRUE,
   identify = TRUE,
@@ -135,8 +135,12 @@ prune <- function(
         matrices <- c(matrices,"omega_mu")
       }
       
-    } else if (x@model == "dlvm1"){
-      matrices <- c("beta")
+    } else if (x@model %in% c("ml_lvm","dlvm1")){
+      if (x@model == "dlvm1") {
+        matrices <- c("beta")
+      } else {
+        matrices <- character(0)
+      }
       if (x@types$within_latent == "prec"){
         matrices <- c(matrices,"kappa_zeta_within")
       } else if (x@types$within_latent == "ggm"){
